@@ -22,14 +22,14 @@ using namespace Qt::Literals::StringLiterals;
 
 KProcessRunner::LaunchMode calculateLaunchMode()
 {
-    // overrides for unit test purposes
-    if (Q_UNLIKELY(qEnvironmentVariableIntValue("KDE_APPLICATIONS_AS_SERVICE"))) {
+    // overrides for unit test purposes. These are considered internal, private and may change in the future.
+    if (Q_UNLIKELY(qEnvironmentVariableIntValue("_KDE_APPLICATIONS_AS_SERVICE"))) {
         return KProcessRunner::SystemdAsService;
     }
-    if (Q_UNLIKELY(qEnvironmentVariableIntValue("KDE_APPLICATIONS_AS_SCOPE"))) {
+    if (Q_UNLIKELY(qEnvironmentVariableIntValue("_KDE_APPLICATIONS_AS_SCOPE"))) {
         return KProcessRunner::SystemdAsScope;
     }
-    if (Q_UNLIKELY(qEnvironmentVariableIntValue("KDE_APPLICATIONS_AS_FORKING"))) {
+    if (Q_UNLIKELY(qEnvironmentVariableIntValue("_KDE_APPLICATIONS_AS_FORKING"))) {
         return KProcessRunner::Forking;
     }
 
@@ -40,13 +40,13 @@ KProcessRunner::LaunchMode calculateLaunchMode()
     QDBusReply<QDBusVariant> reply = bus.call(queryVersionMessage);
     QVersionNumber systemdVersion = QVersionNumber::fromString(reply.value().variant().toString());
     if (systemdVersion.isNull()) {
+        qCWarning(KIO_GUI) << "Failed to determine systemd version, falling back to extremely legacy forking mode.";
         return KProcessRunner::Forking;
     }
-    if (systemdVersion.majorVersion() >= 250) { // first version with ExitType=cgroup, which won't cleanup when the first process exits
-        return KProcessRunner::SystemdAsService;
-    } else {
+    if (systemdVersion.majorVersion() < 250) { // first version with ExitType=cgroup, which won't cleanup when the first process exits
         return KProcessRunner::SystemdAsScope;
     }
+    return KProcessRunner::SystemdAsService;
 }
 
 KProcessRunner::LaunchMode SystemdProcessRunner::modeAvailable()
@@ -78,7 +78,7 @@ bool SystemdProcessRunner::waitForStarted(int timeout)
     }
     QEventLoop loop;
     bool success = false;
-    loop.connect(this, &KProcessRunner::processStarted, [&loop, &success]() {
+    loop.connect(this, &KProcessRunner::processStarted, this, [&loop, &success]() {
         loop.quit();
         success = true;
     });
